@@ -59,7 +59,7 @@ static int debugLevel() {
     static int level = -1;
     if (level < 1) {
         level = 0;
-        QString pulseenv = qgetenv("PHONON_PULSEAUDIO_DEBUG");
+        QByteArray pulseenv = qgetenv("PHONON_PULSEAUDIO_DEBUG");
         int l = pulseenv.toInt();
         if (l > 0)
             level = (l > 2 ? 2 : l);
@@ -74,18 +74,18 @@ static void logMessage(const QString &message, int priority, QObject *obj)
         QString output;
         if (obj) {
             // Strip away namespace from className
-            QString className(obj->metaObject()->className());
+            QByteArray className(obj->metaObject()->className());
             int nameLength = className.length() - className.lastIndexOf(':') - 1;
             className = className.right(nameLength);
             output.sprintf("%s %s (%s %p)", message.toLatin1().constData(),
                            obj->objectName().toLatin1().constData(),
-                           className.toLatin1().constData(), obj);
+                           className.constData(), obj);
         }
         else {
             output = message;
         }
         if (priority <= debugLevel()) {
-            qDebug() << QString("PulseSupport(%1): %2").arg(priority).arg(output);
+            qDebug() << QString::fromLatin1("PulseSupport(%1): %2").arg(priority).arg(output);
         }
     }
 }
@@ -99,7 +99,7 @@ class AudioDevice
         : pulseName(name), pulseIndex(index)
         {
             properties["name"] = desc;
-            properties["description"] = ""; // We don't have descriptions (well we do, but we use them as the name!)
+            properties["description"] = QLatin1String(""); // We don't have descriptions (well we do, but we use them as the name!)
             properties["icon"] = icon;
             properties["available"] = (index != PA_INVALID_INDEX);
             properties["isAdvanced"] = false; // Nothing is advanced!
@@ -174,8 +174,8 @@ static void createGenericDevices()
     s_outputDevices.clear();
     s_outputDevicePriorities.clear();
     index = s_deviceIndexCounter++;
-    s_outputDeviceIndexes.insert("sink:default", index);
-    s_outputDevices.insert(index, AudioDevice("sink:default", QObject::tr("PulseAudio Sound Server"), "audio-backend-pulseaudio", 0));
+    s_outputDeviceIndexes.insert(QLatin1String("sink:default"), index);
+    s_outputDevices.insert(index, AudioDevice(QLatin1String("sink:default"), QObject::tr("PulseAudio Sound Server"), QLatin1String("audio-backend-pulseaudio"), 0));
     for (int i = Phonon::NoCategory; i <= Phonon::LastCategory; ++i) {
         Phonon::Category cat = static_cast<Phonon::Category>(i);
         s_outputDevicePriorities[cat].insert(0, index);
@@ -185,8 +185,8 @@ static void createGenericDevices()
     s_captureDevices.clear();
     s_captureDevicePriorities.clear();
     index = s_deviceIndexCounter++;
-    s_captureDeviceIndexes.insert("source:default", index);
-    s_captureDevices.insert(index, AudioDevice("source:default", QObject::tr("PulseAudio Sound Server"), "audio-backend-pulseaudio", 0));
+    s_captureDeviceIndexes.insert(QLatin1String("source:default"), index);
+    s_captureDevices.insert(index, AudioDevice(QLatin1String("source:default"), QObject::tr("PulseAudio Sound Server"), QLatin1String("audio-backend-pulseaudio"), 0));
     for (int i = Phonon::NoCategory; i <= Phonon::LastCategory; ++i) {
         Phonon::Category cat = static_cast<Phonon::Category>(i);
         s_captureDevicePriorities[cat].insert(0, index);
@@ -201,9 +201,9 @@ static void ext_device_manager_read_cb(pa_context *c, const pa_ext_device_manage
     PulseUserData *u = reinterpret_cast<PulseUserData*>(userdata);
 
     if (eol < 0) {
-        logMessage(QString("Failed to initialize device manager extension: %1").arg(pa_strerror(pa_context_errno(c))));
+        logMessage(QString::fromLatin1("Failed to initialize device manager extension: %1").arg(pa_strerror(pa_context_errno(c))));
         if (s_context != c) {
-            logMessage("Falling back to single device mode");
+            logMessage(QLatin1String("Falling back to single device mode"));
             // Only create our gerneric devices during the probe phase.
             createGenericDevices();
             // As this is our probe phase, exit immediately
@@ -398,7 +398,7 @@ static void ext_device_manager_subscribe_cb(pa_context *c, void *) {
     pa_operation *o;
     PulseUserData *u = new PulseUserData;
     if (!(o = pa_ext_device_manager_read(c, ext_device_manager_read_cb, u))) {
-        logMessage(QString("pa_ext_device_manager_read() failed."));
+        logMessage(QString::fromLatin1("pa_ext_device_manager_read() failed."));
         delete u;
         return;
     }
@@ -414,7 +414,7 @@ static void sink_input_cb(pa_context *c, const pa_sink_input_info *i, int eol, v
         if (pa_context_errno(c) == PA_ERR_NOENTITY)
             return;
 
-        logMessage(QString("Sink input callback failure"));
+        logMessage(QLatin1String("Sink input callback failure"));
         return;
     }
 
@@ -426,10 +426,10 @@ static void sink_input_cb(pa_context *c, const pa_sink_input_info *i, int eol, v
     // loop through (*i) and extract phonon->streamindex...
     const char *t;
     if ((t = pa_proplist_gets(i->proplist, "phonon.streamid"))) {
-        logMessage(QString("Found PulseAudio stream index %1 for Phonon Output Stream %2").arg(i->index).arg(t));
+        logMessage(QString::fromLatin1("Found PulseAudio stream index %1 for Phonon Output Stream %2").arg(i->index).arg(QLatin1String(t)));
 
         // We only care about our own streams (other phonon processes are irrelevent)
-        if (s_outputStreams.contains(QString(t))) {
+        if (s_outputStreams.contains(QLatin1String(t))) {
             PulseStream *stream = s_outputStreams[QString(t)];
             stream->setIndex(i->index);
             stream->setVolume(&i->volume);
@@ -457,7 +457,7 @@ static void source_output_cb(pa_context *c, const pa_source_output_info *i, int
         if (pa_context_errno(c) == PA_ERR_NOENTITY)
             return;
 
-        logMessage(QString("Source output callback failure"));
+        logMessage(QLatin1String("Source output callback failure"));
         return;
     }
 
@@ -469,10 +469,10 @@ static void source_output_cb(pa_context *c, const pa_source_output_info *i, int
     // loop through (*i) and extract phonon->streamindex...
     const char *t;
     if ((t = pa_proplist_gets(i->proplist, "phonon.streamid"))) {
-        logMessage(QString("Found PulseAudio stream index %1 for Phonon Capture Stream %2").arg(i->index).arg(t));
+        logMessage(QString::fromLatin1("Found PulseAudio stream index %1 for Phonon Capture Stream %2").arg(i->index).arg(QLatin1String(t)));
 
         // We only care about our own streams (other phonon processes are irrelevent)
-        if (s_captureStreams.contains(QString(t))) {
+        if (s_captureStreams.contains(QLatin1String(t))) {
             PulseStream *stream = s_captureStreams[QString(t)];
             stream->setIndex(i->index);
             //stream->setVolume(&i->volume);
@@ -500,13 +500,13 @@ static void subscribe_cb(pa_context *c, pa_subscription_event_type_t t, uint32_t
             if ((t & PA_SUBSCRIPTION_EVENT_TYPE_MASK) == PA_SUBSCRIPTION_EVENT_REMOVE) {
                 PulseStream *stream = findStreamByPulseIndex(s_outputStreams, index);
                 if (stream) {
-                    logMessage(QString("Phonon Output Stream %1 is gone at the PA end. Marking it as invalid in our cache as we may reuse it.").arg(stream->uuid()));
+                    logMessage(QString::fromLatin1("Phonon Output Stream %1 is gone at the PA end. Marking it as invalid in our cache as we may reuse it.").arg(stream->uuid()));
                     stream->setIndex(PA_INVALID_INDEX);
                 }
             } else {
                 pa_operation *o;
                 if (!(o = pa_context_get_sink_input_info(c, index, sink_input_cb, NULL))) {
-                    logMessage(QString("pa_context_get_sink_input_info() failed"));
+                    logMessage(QString::fromLatin1("pa_context_get_sink_input_info() failed"));
                     return;
                 }
                 pa_operation_unref(o);
@@ -517,13 +517,13 @@ static void subscribe_cb(pa_context *c, pa_subscription_event_type_t t, uint32_t
             if ((t & PA_SUBSCRIPTION_EVENT_TYPE_MASK) == PA_SUBSCRIPTION_EVENT_REMOVE) {
               PulseStream *stream = findStreamByPulseIndex(s_captureStreams, index);
               if (stream) {
-                    logMessage(QString("Phonon Capture Stream %1 is gone at the PA end. Marking it as invalid in our cache as we may reuse it.").arg(stream->uuid()));
+                    logMessage(QString::fromLatin1("Phonon Capture Stream %1 is gone at the PA end. Marking it as invalid in our cache as we may reuse it.").arg(stream->uuid()));
                     stream->setIndex(PA_INVALID_INDEX);
                 }
             } else {
                 pa_operation *o;
                 if (!(o = pa_context_get_source_output_info(c, index, source_output_cb, NULL))) {
-                    logMessage(QString("pa_context_get_sink_input_info() failed"));
+                    logMessage(QString::fromLatin1("pa_context_get_sink_input_info() failed"));
                     return;
                 }
                 pa_operation_unref(o);
@@ -533,29 +533,27 @@ static void subscribe_cb(pa_context *c, pa_subscription_event_type_t t, uint32_t
 }
 
 
-static const char* statename(pa_context_state_t state)
+static QString statename(pa_context_state_t state)
 {
     switch (state)
     {
-        case PA_CONTEXT_UNCONNECTED:  return "Unconnected";
-        case PA_CONTEXT_CONNECTING:   return "Connecting";
-        case PA_CONTEXT_AUTHORIZING:  return "Authorizing";
-        case PA_CONTEXT_SETTING_NAME: return "Setting Name";
-        case PA_CONTEXT_READY:        return "Ready";
-        case PA_CONTEXT_FAILED:       return "Failed";
-        case PA_CONTEXT_TERMINATED:   return "Terminated";
+        case PA_CONTEXT_UNCONNECTED:  return QLatin1String("Unconnected");
+        case PA_CONTEXT_CONNECTING:   return QLatin1String("Connecting");
+        case PA_CONTEXT_AUTHORIZING:  return QLatin1String("Authorizing");
+        case PA_CONTEXT_SETTING_NAME: return QLatin1String("Setting Name");
+        case PA_CONTEXT_READY:        return QLatin1String("Ready");
+        case PA_CONTEXT_FAILED:       return QLatin1String("Failed");
+        case PA_CONTEXT_TERMINATED:   return QLatin1String("Terminated");
     }
 
-    static QString unknown;
-    unknown = QString("Unknown state: %0").arg(state);
-    return unknown.toAscii().constData();
+    return QString::fromLatin1("Unknown state: %0").arg(state);
 }
 
 static void context_state_callback(pa_context *c, void *)
 {
     Q_ASSERT(c);
 
-    logMessage(QString("context_state_callback %1").arg(statename(pa_context_get_state(c))));
+    logMessage(QString::fromLatin1("context_state_callback %1").arg(statename(pa_context_get_state(c))));
     pa_context_state_t state = pa_context_get_state(c);
     if (state == PA_CONTEXT_READY) {
         // We've connected to PA, so it is active
@@ -571,7 +569,7 @@ static void context_state_callback(pa_context *c, void *)
             if (!(o = pa_context_subscribe(c, (pa_subscription_mask_t)
                                               (PA_SUBSCRIPTION_MASK_SINK_INPUT|
                                                PA_SUBSCRIPTION_MASK_SOURCE_OUTPUT), NULL, NULL))) {
-                logMessage(QString("pa_context_subscribe() failed"));
+                logMessage(QLatin1String("pa_context_subscribe() failed"));
                 return;
             }
             pa_operation_unref(o);
@@ -581,22 +579,22 @@ static void context_state_callback(pa_context *c, void *)
             // and then load up info about all streams.
             for (QMap<QString, PulseStream*>::iterator it = s_outputStreams.begin(); it != s_outputStreams.end(); ++it) {
               PulseStream *stream = *it;
-              logMessage(QString("Phonon Output Stream %1 is gone at the PA end. Marking it as invalid in our cache as we may reuse it.").arg(stream->uuid()));
+              logMessage(QString::fromLatin1("Phonon Output Stream %1 is gone at the PA end. Marking it as invalid in our cache as we may reuse it.").arg(stream->uuid()));
               stream->setIndex(PA_INVALID_INDEX);
             }
             if (!(o = pa_context_get_sink_input_info_list(c, sink_input_cb, NULL))) {
-              logMessage(QString("pa_context_get_sink_input_info_list() failed"));
+              logMessage(QString::fromLatin1("pa_context_get_sink_input_info_list() failed"));
               return;
             }
             pa_operation_unref(o);
 
             for (QMap<QString, PulseStream*>::iterator it = s_captureStreams.begin(); it != s_captureStreams.end(); ++it) {
               PulseStream *stream = *it;
-              logMessage(QString("Phonon Capture Stream %1 is gone at the PA end. Marking it as invalid in our cache as we may reuse it.").arg(stream->uuid()));
+              logMessage(QString::fromLatin1("Phonon Capture Stream %1 is gone at the PA end. Marking it as invalid in our cache as we may reuse it.").arg(stream->uuid()));
               stream->setIndex(PA_INVALID_INDEX);
             }
             if (!(o = pa_context_get_source_output_info_list(c, source_output_cb, NULL))) {
-              logMessage(QString("pa_context_get_source_output_info_list() failed"));
+              logMessage(QString::fromLatin1("pa_context_get_source_output_info_list() failed"));
               return;
             }
             pa_operation_unref(o);
@@ -607,7 +605,7 @@ static void context_state_callback(pa_context *c, void *)
         if (s_context == c) {
             pa_ext_device_manager_set_subscribe_cb(c, ext_device_manager_subscribe_cb, NULL);
             if (!(o = pa_ext_device_manager_subscribe(c, 1, NULL, NULL))) {
-                logMessage(QString("pa_ext_device_manager_subscribe() failed"));
+                logMessage(QString::fromLatin1("pa_ext_device_manager_subscribe() failed"));
                 return;
             }
             pa_operation_unref(o);
@@ -617,7 +615,7 @@ static void context_state_callback(pa_context *c, void *)
         PulseUserData *u = new PulseUserData;
         if (!(o = pa_ext_device_manager_read(c, ext_device_manager_read_cb, u))) {
             if (s_context != c) {
-                logMessage(QString("pa_ext_device_manager_read() failed. Attempting to continue without device manager support"));
+                logMessage(QString::fromLatin1("pa_ext_device_manager_read() failed. Attempting to continue without device manager support"));
                 // Only create our gerneric devices during the probe phase.
                 createGenericDevices();
                 // As this is our probe phase, exit immediately
@@ -684,10 +682,10 @@ void PulseSupport::shutdown()
 void PulseSupport::debug()
 {
 #ifdef HAVE_PULSEAUDIO
-    logMessage(QString("Have we been initialised yet? %1").arg(s_instance ? "Yes" : "No"));
+    logMessage(QString::fromLatin1("Have we been initialised yet? %1").arg(s_instance ? "Yes" : "No"));
     if (s_instance) {
-        logMessage(QString("Connected to PulseAudio? %1").arg(s_pulseActive ? "Yes" : "No"));
-        logMessage(QString("PulseAudio support 'Active'? %1").arg(s_instance->isActive() ? "Yes" : "No"));
+        logMessage(QString::fromLatin1("Connected to PulseAudio? %1").arg(s_pulseActive ? "Yes" : "No"));
+        logMessage(QString::fromLatin1("PulseAudio support 'Active'? %1").arg(s_instance->isActive() ? "Yes" : "No"));
     }
 #endif
 }
@@ -697,26 +695,26 @@ PulseSupport::PulseSupport()
 {
 #ifdef HAVE_PULSEAUDIO
     // Initialise our map (is there a better way to do this?)
-    s_roleCategoryMap["none"] = Phonon::NoCategory;
-    s_roleCategoryMap["video"] = Phonon::VideoCategory;
-    s_roleCategoryMap["music"] = Phonon::MusicCategory;
-    s_roleCategoryMap["game"] = Phonon::GameCategory;
-    s_roleCategoryMap["event"] = Phonon::NotificationCategory;
-    s_roleCategoryMap["phone"] = Phonon::CommunicationCategory;
-    //s_roleCategoryMap["animation"]; // No Mapping
-    //s_roleCategoryMap["production"]; // No Mapping
-    s_roleCategoryMap["a11y"] = Phonon::AccessibilityCategory;
+    s_roleCategoryMap[QLatin1String("none")] = Phonon::NoCategory;
+    s_roleCategoryMap[QLatin1String("video")] = Phonon::VideoCategory;
+    s_roleCategoryMap[QLatin1String("music")] = Phonon::MusicCategory;
+    s_roleCategoryMap[QLatin1String("game")] = Phonon::GameCategory;
+    s_roleCategoryMap[QLatin1String("event")] = Phonon::NotificationCategory;
+    s_roleCategoryMap[QLatin1String("phone")] = Phonon::CommunicationCategory;
+    //s_roleCategoryMap[QLatin1String("animation")]; // No Mapping
+    //s_roleCategoryMap[QLatin1String("production")]; // No Mapping
+    s_roleCategoryMap[QLatin1String("a11y")] = Phonon::AccessibilityCategory;
 
     // To allow for easy debugging, give an easy way to disable this pulseaudio check
-    QString pulseenv = qgetenv("PHONON_PULSEAUDIO_DISABLE");
+    QByteArray pulseenv = qgetenv("PHONON_PULSEAUDIO_DISABLE");
     if (pulseenv.toInt()) {
-        logMessage("PulseAudio support disabled: PHONON_PULSEAUDIO_DISABLE is set");
+        logMessage(QLatin1String("PulseAudio support disabled: PHONON_PULSEAUDIO_DISABLE is set"));
         return;
     }
 
     // We require a glib event loop
-    if (QLatin1String(QAbstractEventDispatcher::instance()->metaObject()->className())
-            != "QGuiEventDispatcherGlib") {
+    if (strcmp(QAbstractEventDispatcher::instance()->metaObject()->className(),
+               "QGuiEventDispatcherGlib") != 0) {
         qWarning("WARNING: Disabling PulseAudio integration for lack of GLib event loop.");
         return;
     }
@@ -725,21 +723,21 @@ PulseSupport::PulseSupport()
     // use a fully async integrated mainloop method to connect and get proper support.
     pa_mainloop *p_test_mainloop;
     if (!(p_test_mainloop = pa_mainloop_new())) {
-        logMessage("PulseAudio support disabled: Unable to create mainloop");
+        logMessage(QLatin1String("PulseAudio support disabled: Unable to create mainloop"));
         return;
     }
 
     pa_context *p_test_context;
     if (!(p_test_context = pa_context_new(pa_mainloop_get_api(p_test_mainloop), "libphonon-probe"))) {
-        logMessage("PulseAudio support disabled: Unable to create context");
+        logMessage(QLatin1String("PulseAudio support disabled: Unable to create context"));
         pa_mainloop_free(p_test_mainloop);
         return;
     }
 
-    logMessage("Probing for PulseAudio...");
+    logMessage(QLatin1String("Probing for PulseAudio..."));
     // (cg) Convert to PA_CONTEXT_NOFLAGS when PulseAudio 0.9.19 is required
     if (pa_context_connect(p_test_context, NULL, static_cast<pa_context_flags_t>(0), NULL) < 0) {
-        logMessage(QString("PulseAudio support disabled: %1").arg(pa_strerror(pa_context_errno(p_test_context))));
+        logMessage(QString::fromLatin1("PulseAudio support disabled: %1").arg(QString::fromLocal8Bit(pa_strerror(pa_context_errno(p_test_context)))));
         pa_context_disconnect(p_test_context);
         pa_context_unref(p_test_context);
         pa_mainloop_free(p_test_mainloop);
@@ -751,7 +749,7 @@ PulseSupport::PulseSupport()
         pa_mainloop_iterate(p_test_mainloop, 1, NULL);
 
         if (!PA_CONTEXT_IS_GOOD(pa_context_get_state(p_test_context))) {
-            logMessage("PulseAudio probe complete.");
+            logMessage(QLatin1String("PulseAudio probe complete."));
             break;
         }
     }
@@ -760,12 +758,12 @@ PulseSupport::PulseSupport()
     pa_mainloop_free(p_test_mainloop);
 
     if (!s_pulseActive) {
-        logMessage("PulseAudio support is not available.");
+        logMessage(QLatin1String("PulseAudio support is not available."));
         return;
     }
 
     // If we're still here, PA is available.
-    logMessage("PulseAudio support enabled");
+    logMessage(QLatin1String("PulseAudio support enabled"));
 
     // Now we connect for real using a proper main loop that we can forget
     // all about processing.
@@ -816,7 +814,7 @@ void PulseSupport::enable(bool enabled)
 {
     mEnabled = enabled;
 #ifdef HAVE_PULSEAUDIO
-    logMessage(QString("Enabled Breakdown: mEnabled: %1, s_pulseActive %2").arg(mEnabled ? "Yes" : "No" ).arg(s_pulseActive ? "Yes" : "No"));
+    logMessage(QString::fromLocal8Bit("Enabled Breakdown: mEnabled: %1, s_pulseActive %2").arg(mEnabled ? "Yes" : "No" ).arg(s_pulseActive ? "Yes" : "No"));
 #endif
 }
 
@@ -925,7 +923,7 @@ static void setDevicePriority(Category category, QStringList list)
     if (role.isEmpty())
         return;
 
-    logMessage(QString("Reindexing %1: %2").arg(role).arg(list.join(", ")));
+    logMessage(QString::fromLatin1("Reindexing %1: %2").arg(role).arg(list.join(QLatin1String(", "))));
 
     char **devices;
     devices = pa_xnew(char *, list.size()+1);
@@ -938,7 +936,7 @@ static void setDevicePriority(Category category, QStringList list)
 #ifdef HAVE_PULSEAUDIO_DEVICE_MANAGER
     pa_operation *o;
     if (!(o = pa_ext_device_manager_reorder_devices_for_role(s_context, role.toUtf8().constData(), (const char**)devices, NULL, NULL)))
-        logMessage(QString("pa_ext_device_manager_reorder_devices_for_role() failed"));
+        logMessage(QString::fromLatin1("pa_ext_device_manager_reorder_devices_for_role() failed"));
     else
         pa_operation_unref(o);
 #endif
@@ -988,10 +986,10 @@ void PulseSupport::setCaptureDevicePriorityForCategory(Category category, QList<
 #ifdef HAVE_PULSEAUDIO
 static PulseStream* register_stream(QMap<QString,PulseStream*> &map, QString streamUuid, Category category)
 {
-    logMessage(QString("Initialising streamindex %1").arg(streamUuid));
+    logMessage(QString::fromLatin1("Initialising streamindex %1").arg(streamUuid));
     QString role = s_roleCategoryMap.key(category);
     if (!role.isEmpty()) {
-        logMessage(QString("Setting role to %1 for streamindex %2").arg(role).arg(streamUuid));
+        logMessage(QString::fromLatin1("Setting role to %1 for streamindex %2").arg(role).arg(streamUuid));
         setenv("PULSE_PROP_media.role", role.toLatin1().constData(), 1);
     }
     setenv("PULSE_PROP_phonon.streamid", streamUuid.toLatin1().constData(), 1);
@@ -1035,7 +1033,7 @@ bool PulseSupport::setOutputName(QString streamUuid, QString name) {
     Q_UNUSED(name);
     return false;
 #else
-    logMessage(QString("Unimplemented: Need to find a way to set either application.name or media.name in SI proplist"));
+    logMessage(QString::fromLatin1("Unimplemented: Need to find a way to set either application.name or media.name in SI proplist"));
     Q_UNUSED(streamUuid);
     Q_UNUSED(name);
     return true;
@@ -1052,30 +1050,30 @@ bool PulseSupport::setOutputDevice(QString streamUuid, int device) {
         return true;
 
     if (!s_outputDevices.contains(device)) {
-        logMessage(QString("Attempting to set Output Device for invalid device id %1.").arg(device));
+        logMessage(QString::fromLatin1("Attempting to set Output Device for invalid device id %1.").arg(device));
         return false;
     }
     const QVariant var = s_outputDevices[device].properties["name"];
-    logMessage(QString("Attempting to set Output Device to '%1' for Output Stream %2").arg(var.toString()).arg(streamUuid));
+    logMessage(QString::fromLatin1("Attempting to set Output Device to '%1' for Output Stream %2").arg(var.toString()).arg(streamUuid));
 
     // Attempt to look up the pulse stream index.
     if (s_outputStreams.contains(streamUuid) && s_outputStreams[streamUuid]->index() != PA_INVALID_INDEX) {
-        logMessage(QString("... Found in map. Moving now"));
+        logMessage(QString::fromLatin1("... Found in map. Moving now"));
 
         uint32_t pulse_device_index = s_outputDevices[device].pulseIndex;
         uint32_t pulse_stream_index = s_outputStreams[streamUuid]->index();
 
-        logMessage(QString("Moving Pulse Sink Input %1 to '%2' (Pulse Sink %3)").arg(pulse_stream_index).arg(var.toString()).arg(pulse_device_index));
+        logMessage(QString::fromLatin1("Moving Pulse Sink Input %1 to '%2' (Pulse Sink %3)").arg(pulse_stream_index).arg(var.toString()).arg(pulse_device_index));
 
         /// @todo Find a way to move the stream without saving it... We don't want to pollute the stream restore db.
         pa_operation* o;
         if (!(o = pa_context_move_sink_input_by_index(s_context, pulse_stream_index, pulse_device_index, NULL, NULL))) {
-            logMessage(QString("pa_context_move_sink_input_by_index() failed"));
+            logMessage(QString::fromLatin1("pa_context_move_sink_input_by_index() failed"));
             return false;
         }
         pa_operation_unref(o);
     } else {
-        logMessage(QString("... Not found in map. We will be notified of the device when the stream appears and we can process any moves needed then"));
+        logMessage(QString::fromLatin1("... Not found in map. We will be notified of the device when the stream appears and we can process any moves needed then"));
     }
     return true;
 #endif
@@ -1087,7 +1085,7 @@ bool PulseSupport::setOutputVolume(QString streamUuid, qreal volume) {
     Q_UNUSED(volume);
     return false;
 #else
-    logMessage(QString("Attempting to set volume to %1 for Output Stream %2").arg(volume).arg(streamUuid));
+    logMessage(QString::fromLatin1("Attempting to set volume to %1 for Output Stream %2").arg(volume).arg(streamUuid));
 
     // Attempt to look up the pulse stream index.
     if (s_outputStreams.contains(streamUuid) && s_outputStreams[streamUuid]->index() != PA_INVALID_INDEX) {
@@ -1095,17 +1093,17 @@ bool PulseSupport::setOutputVolume(QString streamUuid, qreal volume) {
 
         uint8_t channels = stream->channels();
         if (channels < 1) {
-            logMessage("Channel count is less than 1. Cannot set volume.");
+            logMessage(QString::fromLatin1("Channel count is less than 1. Cannot set volume."));
             return false;
         }
 
         pa_cvolume vol;
         pa_cvolume_set(&vol, channels, (volume * PA_VOLUME_NORM));
 
-        logMessage(QString("Found PA index %1. Calling pa_context_set_sink_input_volume()").arg(stream->index()));
+        logMessage(QString::fromLatin1("Found PA index %1. Calling pa_context_set_sink_input_volume()").arg(stream->index()));
         pa_operation* o;
         if (!(o = pa_context_set_sink_input_volume(s_context, stream->index(), &vol, NULL, NULL))) {
-            logMessage(QString("pa_context_set_sink_input_volume() failed"));
+            logMessage(QString::fromLatin1("pa_context_set_sink_input_volume() failed"));
             return false;
         }
         pa_operation_unref(o);
@@ -1120,16 +1118,16 @@ bool PulseSupport::setOutputMute(QString streamUuid, bool mute) {
     Q_UNUSED(mute);
     return false;
 #else
-    logMessage(QString("Attempting to %1 mute for Output Stream %2").arg(mute ? "set" : "unset").arg(streamUuid));
+    logMessage(QString::fromLatin1("Attempting to %1 mute for Output Stream %2").arg(mute ? "set" : "unset").arg(streamUuid));
 
     // Attempt to look up the pulse stream index.
     if (s_outputStreams.contains(streamUuid) && s_outputStreams[streamUuid]->index() != PA_INVALID_INDEX) {
         PulseStream *stream = s_outputStreams[streamUuid];
 
-        logMessage(QString("Found PA index %1. Calling pa_context_set_sink_input_mute()").arg(stream->index()));
+        logMessage(QString::fromLatin1("Found PA index %1. Calling pa_context_set_sink_input_mute()").arg(stream->index()));
         pa_operation* o;
         if (!(o = pa_context_set_sink_input_mute(s_context, stream->index(), (mute ? 1 : 0), NULL, NULL))) {
-            logMessage(QString("pa_context_set_sink_input_mute() failed"));
+            logMessage(QString::fromLatin1("pa_context_set_sink_input_mute() failed"));
             return false;
         }
         pa_operation_unref(o);
@@ -1148,30 +1146,30 @@ bool PulseSupport::setCaptureDevice(QString streamUuid, int device) {
         return true;
 
     if (!s_captureDevices.contains(device)) {
-        logMessage(QString("Attempting to set Capture Device for invalid device id %1.").arg(device));
+        logMessage(QString::fromLatin1("Attempting to set Capture Device for invalid device id %1.").arg(device));
         return false;
     }
     const QVariant var = s_captureDevices[device].properties["name"];
-    logMessage(QString("Attempting to set Capture Device to '%1' for Capture Stream %2").arg(var.toString()).arg(streamUuid));
+    logMessage(QString::fromLatin1("Attempting to set Capture Device to '%1' for Capture Stream %2").arg(var.toString()).arg(streamUuid));
 
     // Attempt to look up the pulse stream index.
     if (s_captureStreams.contains(streamUuid) && s_captureStreams[streamUuid]->index() == PA_INVALID_INDEX) {
-        logMessage(QString("... Found in map. Moving now"));
+        logMessage(QString::fromLatin1("... Found in map. Moving now"));
 
         uint32_t pulse_device_index = s_captureDevices[device].pulseIndex;
         uint32_t pulse_stream_index = s_captureStreams[streamUuid]->index();
 
-        logMessage(QString("Moving Pulse Source Output %1 to '%2' (Pulse Sink %3)").arg(pulse_stream_index).arg(var.toString()).arg(pulse_device_index));
+        logMessage(QString::fromLatin1("Moving Pulse Source Output %1 to '%2' (Pulse Sink %3)").arg(pulse_stream_index).arg(var.toString()).arg(pulse_device_index));
 
         /// @todo Find a way to move the stream without saving it... We don't want to pollute the stream restore db.
         pa_operation* o;
         if (!(o = pa_context_move_source_output_by_index(s_context, pulse_stream_index, pulse_device_index, NULL, NULL))) {
-            logMessage(QString("pa_context_move_source_output_by_index() failed"));
+            logMessage(QString::fromLatin1("pa_context_move_source_output_by_index() failed"));
             return false;
         }
         pa_operation_unref(o);
     } else {
-        logMessage(QString("... Not found in map. We will be notified of the device when the stream appears and we can process any moves needed then"));
+        logMessage(QString::fromLatin1("... Not found in map. We will be notified of the device when the stream appears and we can process any moves needed then"));
     }
     return true;
 #endif
@@ -1182,7 +1180,7 @@ void PulseSupport::clearStreamCache(QString streamUuid) {
     Q_UNUSED(streamUuid);
     return;
 #else
-    logMessage(QString("Clearing stream cache for stream %1").arg(streamUuid));
+    logMessage(QString::fromLatin1("Clearing stream cache for stream %1").arg(streamUuid));
     if (s_outputStreams.contains(streamUuid)) {
         PulseStream *stream = s_outputStreams[streamUuid];
         s_outputStreams.remove(streamUuid);
