@@ -6,7 +6,7 @@
     License as published by the Free Software Foundation; either
     version 2.1 of the License, or (at your option) version 3, or any
     later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), Trolltech ASA 
+    successor approved by the membership of KDE e.V.), Nokia Corporation
     (or its successors, if any) and the KDE Free Qt Foundation, which shall
     act as a proxy defined in Section 6 of version 3 of the license.
 
@@ -15,7 +15,7 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     Lesser General Public License for more details.
 
-    You should have received a copy of the GNU Lesser General Public 
+    You should have received a copy of the GNU Lesser General Public
     License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 
 */
@@ -23,7 +23,7 @@
 #define Phonon_FAKE_AUDIODATAOUTPUT_H
 
 #include "abstractaudiooutput.h"
-#include <phonon/experimental/audiodataoutput.h>
+#include <phonon/audiodataoutput.h>
 #include <QtCore/QVector>
 
 namespace Phonon
@@ -41,10 +41,8 @@ namespace Fake
             ~AudioDataOutput();
 
         public Q_SLOTS:
-            Phonon::Experimental::AudioDataOutput::Format format() const;
             int dataSize() const;
             int sampleRate() const;
-            void setFormat(Phonon::Experimental::AudioDataOutput::Format format);
             void setDataSize(int size);
 
         public:
@@ -52,14 +50,12 @@ namespace Fake
             virtual void processBuffer(QVector<float> &buffer);
 
         signals:
-            void dataReady(const QMap<Phonon::Experimental::AudioDataOutput::Channel, QVector<qint16> > &data);
-            void dataReady(const QMap<Phonon::Experimental::AudioDataOutput::Channel, QVector<float> > &data);
+            void dataReady(const QMap<Phonon::AudioDataOutput::Channel, QVector<qint16> > &data);
             void endOfMedia(int remainingSamples);
 
         private:
             void convertAndEmit(const QVector<float> &buffer);
 
-            Phonon::Experimental::AudioDataOutput::Format m_format;
             int m_dataSize;
             QVector<float> m_pendingData;
     };
